# gitsane | README

* * *

## Summary

**gitsane** Repository Manager

 Version: 0.1.1

* * *

## Purpose

Have dozens of local repositories to manage?  If you are like me and your average dev machine has over a 100 git repositories in various states, managing the sprawl can be maddening.

Don't get mad - get your sanity back.

[gitsane](https://github.com/fstab50/gitsane) is a CLI utility for maintaining volumes of git repositories on local machine.


## Dependencies



## Installation


## Details



